BTreePageError

Enum BTreePageError 

pub enum BTreePageError {
    PageSizeMismatch {
        expected: usize,
        actual: usize,
    },
    PageTooSmall {
        usable_size: usize,
        needed: usize,
    },
    InvalidPageType {
        raw: u8,
    },
    InvalidFragmentedFreeBytes {
        raw: u8,
        max: u8,
    },
    InvalidCellContentAreaStart {
        raw: u16,
        decoded: u32,
        usable_size: usize,
    },
    CellContentAreaOverlapsCellPointers {
        cell_content_start: u32,
        cell_pointer_array_end: usize,
    },
    CellPointerArrayOutOfBounds {
        start: usize,
        len: usize,
        usable_size: usize,
    },
    InvalidCellPointer {
        index: usize,
        offset: u16,
        usable_size: usize,
    },
    InvalidFreeblock {
        offset: u16,
        size: u16,
        usable_size: usize,
    },
    FreeblockLoop {
        offset: u16,
    },
    InvalidRightMostChild {
        raw: u32,
    },
}
Errors that can occur while parsing B-tree page layout structures.

Variants



PageSizeMismatch

Page buffer did not match the expected page size.

Fields

expected: usize
actual: usize


PageTooSmall

Page did not have enough bytes to read the header.

Fields

usable_size: usize
needed: usize


InvalidPageType

Unknown B-tree page type byte.

Fields

raw: u8


InvalidFragmentedFreeBytes

Fragmented free bytes exceeds the maximum allowed.

Fields

raw: u8
max: u8


InvalidCellContentAreaStart

Cell content area start offset was invalid for this page.

Fields

raw: u16
decoded: u32
usable_size: usize


CellContentAreaOverlapsCellPointers

Cell content area begins before the end of the cell pointer array.

Fields

cell_content_start: u32
cell_pointer_array_end: usize


CellPointerArrayOutOfBounds

Cell pointer array extends past the usable page area.

Fields

start: usize
len: usize
usable_size: usize


InvalidCellPointer

A cell pointer was invalid.

Fields

index: usize
offset: u16
usable_size: usize


InvalidFreeblock

Freeblock offset/size was invalid.

Fields

offset: u16
size: u16
usable_size: usize


FreeblockLoop

Freeblock list contained a loop.

Fields

offset: u16


InvalidRightMostChild

Interior page right-most child pointer was invalid.

Fields

raw: u32