pub struct StructuralEffects(/* private fields */);Expand description
Structural side effects that make operations non-commutative.
Implementations
Sourceimpl StructuralEffects
impl StructuralEffects
Sourcepub const PAGE_SPLIT: Self
pub const PAGE_SPLIT: Self
A B-tree page was split.
Sourcepub const PAGE_MERGE: Self
pub const PAGE_MERGE: Self
A B-tree page was merged.
Sourcepub const BALANCE_MULTI_PAGE: Self
pub const BALANCE_MULTI_PAGE: Self
Multi-page balance operation.
Sourcepub const OVERFLOW_ALLOC: Self
pub const OVERFLOW_ALLOC: Self
An overflow page was allocated.
Sourcepub const OVERFLOW_MUTATE: Self
pub const OVERFLOW_MUTATE: Self
An overflow chain was mutated.
Sourcepub const FREELIST_MUTATE: Self
pub const FREELIST_MUTATE: Self
The freelist was modified.
Sourcepub const POINTER_MAP_MUTATE: Self
pub const POINTER_MAP_MUTATE: Self
The pointer map was modified.
Sourcepub const DEFRAG_MOVE_CELLS: Self
pub const DEFRAG_MOVE_CELLS: Self
Cells were moved during defragmentation.
Sourceimpl StructuralEffects
impl StructuralEffects
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl StructuralEffects
impl StructuralEffects
Sourcepub const fn iter(&self) -> Iter<StructuralEffects>
pub const fn iter(&self) -> Iter<StructuralEffects>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<StructuralEffects>
pub const fn iter_names(&self) -> IterNames<StructuralEffects>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.