pub struct VersionPointer(/* private fields */);Expand description
Opaque pointer to a previous page version in a version chain.
In the implementation this is expected to be an arena index or object locator, not a raw pointer.
Implementations