pub enum DatabaseHeaderError {
InvalidMagic,
InvalidPageSize {
raw: u16,
},
InvalidPayloadFractions {
max: u8,
min: u8,
leaf: u8,
},
UsableSizeTooSmall {
page_size: u32,
reserved_per_page: u8,
usable_size: u32,
},
UnsupportedReadVersion {
read_version: u8,
max_supported: u8,
},
InvalidTextEncoding {
raw: u32,
},
InvalidSchemaFormat {
raw: u32,
},
}Expand description
Errors that can occur while parsing or validating the 100-byte database header.
Variants
InvalidMagic
Magic string mismatch at bytes 0..16.
InvalidPageSize
Page size encoding was invalid.
InvalidPayloadFractions
Embedded payload fractions (bytes 21..24) are invalid.
UsableSizeTooSmall
The effective usable page size would be below the minimum allowed by SQLite (480).
UnsupportedReadVersion
Read file format version is too new to be understood.
InvalidTextEncoding
Text encoding field was not 1/2/3.
InvalidSchemaFormat
Schema format number is unsupported.