Constants
- BTREE_
INTERIOR_ HEADER_ SIZE - Size of a B-tree page header for interior pages.
- BTREE_
LEAF_ HEADER_ SIZE - Size of a B-tree page header for leaf pages.
- BTREE_
MAX_ DEPTH - Maximum depth of B-tree cursor stack (max tree depth). A database with 2^31 pages and a branching factor of 2 would have depth ~31. SQLite uses 20 as a safe maximum.
- BTREE_
MIN_ CELLS - Minimum number of cells on a B-tree page.
- CELL_
POINTER_ SIZE - Size of a cell pointer (u16) in the cell pointer array.
- DB_
HEADER_ SIZE - Size of the database file header in bytes.
- DEFAULT_
CACHE_ SIZE - Default suggested cache size (negative means limit by memory in KB). -2000 means 2048000 bytes = ~2 MB.
- DEFAULT_
PAGE_ SIZE - Default page size in bytes.
- DEFAULT_
WAL_ AUTOCHECKPOINT - Default number of WAL frames before auto-checkpointing.
- MAX_
ALLOCATION_ SIZE - Maximum size of any single memory allocation.
- MAX_
ATTACHED - Maximum number of attached databases.
- MAX_
COLUMN - Maximum number of columns in a table, index, or view. Also the maximum number of terms in SET, result set, GROUP BY, ORDER BY, VALUES.
- MAX_
COMPOUND_ SELECT - Maximum number of terms in a compound SELECT statement.
- MAX_
DEFAULT_ PAGE_ SIZE - Maximum default page size (used for auto-selection).
- MAX_
EXPR_ DEPTH - Maximum depth of an expression tree.
- MAX_
FUNCTION_ ARG - Maximum number of arguments to an SQL function.
- MAX_
LENGTH - Maximum length of a TEXT or BLOB in bytes. Also limits the size of a row in a table or index.
- MAX_
LIKE_ PATTERN_ LENGTH - Maximum length in bytes of a LIKE or GLOB pattern.
- MAX_
PAGE_ COUNT - Maximum number of pages in one database file.
- MAX_
PAGE_ SIZE - Maximum page size in bytes (must be 65536).
- MAX_
PARSER_ DEPTH - Maximum depth of the parser stack.
- MAX_
SQL_ LENGTH - Maximum length of a single SQL statement in bytes.
- MAX_
TRIGGER_ DEPTH - Maximum depth of recursion for triggers.
- MAX_
VARIABLE_ NUMBER - Maximum value of a
?nnnwildcard parameter number. - MAX_
VDBE_ OP - Maximum number of opcodes in a VDBE program.
- MIN_
LENGTH - Minimum allowed value for the length limit.
- WAL_
FRAME_ HEADER_ SIZE - Size of a WAL frame header in bytes.
- WAL_
HEADER_ SIZE - Size of the WAL file header in bytes.
- WAL_
MAGIC_ BE - WAL magic number (big-endian checksums).
- WAL_
MAGIC_ LE - WAL magic number (little-endian checksums).