P4

Enum P4 

pub enum P4 {
Show 14 variants None, Int(i32), Int64(i64), Real(f64), Str(String), Blob(Vec<u8>), Collation(String), FuncName(String), FuncNameCollated(String, String), Table(String), Index(String), Affinity(String), TimeTravelCommitSeq(u64), TimeTravelTimestamp(String),
}
The P4 operand of a VDBE instruction.

P4 is a polymorphic operand that can hold different types depending on the opcode.

Variants



None

No P4 value.



Int(i32)

A 32-bit integer value.



Int64(i64)

A 64-bit integer value.



Real(f64)

A 64-bit float value.



Str(String)

A string value.



Blob(Vec<u8>)

A blob value.



Collation(String)

A collation sequence name.



FuncName(String)

A function name (for Function/PureFunc opcodes).



FuncNameCollated(String, String)

A function name with an associated collation sequence for DISTINCT deduplication in aggregate functions (e.g. COUNT(DISTINCT col) where col has COLLATE NOCASE).



Table(String)

A table name.



Index(String)

An index name (for IdxInsert/IdxDelete opcodes).



Affinity(String)

An affinity string (one char per column).



TimeTravelCommitSeq(u64)

Time-travel target: commit sequence for FOR SYSTEM_TIME AS OF COMMITSEQ <n>.



TimeTravelTimestamp(String)

Time-travel target: ISO-8601 timestamp for FOR SYSTEM_TIME AS OF '<ts>'.