Structs
- Small
Text - A small-string-optimized text value.
- SqlLike
Fast Path Matcher - Reusable matcher for simple LIKE patterns classified by
classify_sql_like_fast_path. - SumAccumulator
- Accumulator for SQL
sum()aggregate with SQLite overflow semantics. - SumOverflow
Error - Error returned when
sum()encounters integer overflow.
Enums
- SqlLike
Fast Path Kind - Sqlite
Value - A dynamically-typed SQLite value.
Functions
- classify_
sql_ like_ fast_ path - format_
sqlite_ float - Format a floating-point value as text matching SQLite’s
%!.*gbehavior. - int_
float_ cmp - Compare an integer with a float, preserving precision for large i64 values.
- pool_
acquire - Acquire a value from the thread-local pool, if available.
- pool_
clear - Clear the thread-local value pool.
- pool_
len - Returns the current number of values in the thread-local pool.
- pool_
return - Return a value to the thread-local pool for reuse.
- pool_
return_ reusable - Return a heap-carrying value to the thread-local pool when preserving its backing allocation is likely to pay off on the next decode/write.
- sql_
like - Match a string against a SQL LIKE pattern with SQLite semantics.
- sql_
like_ cased - Match a string against a SQL LIKE pattern, honoring the connection’s
PRAGMA case_sensitive_likesetting. - sql_
like_ fast_ path_ matches - sql_
like_ fast_ path_ matches_ cased - Like
sql_like_fast_path_matchesbut honoringcase_sensitive. - unique_
key_ duplicates - Check if two composite UNIQUE keys are duplicates (SQLite NULL semantics).